---
layout: page
title: About
slug: about
date: 2017/06/28 17:26:00
status: publish
author: RyomaHan
categories: 
  - Maverick
  - Dev
tags: 
  - theme
---


Maverick is a static blog generator built with python. Like Hexo and Jekyll, it takes Markdown(`.md`) files as input, and output beautifully formated and well structured website pages(`.html`). It has a lot built-in useful features(feed, search, sitemap, etc.), with extended Markdown syntax and enhanced image processing pipeline.

If you are tired of intricate plugins and complicated configurations, just give Maverick a try. You focus on writing, let Maverick take care of the rest.

Pull requests are surely welcome. If you have any questions or suggestions, please head to [issue area](https://github.com/AlanDecode/Maverick/issues) and leave us a message. Before that, let's finish this document.
